
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '36.4.0',
    'branch_nick': 'release-36',
    'revision_id': '0ad86f466615804f67f827a5d1036171396536ed',
    'revno': 13479
}
